<?php
// PukiWiki - Yet another WikiWikiWeb clone.
// pukiwiki.skin.php
// Copyright
//   2023 Department of SocialDesign
//   2002-2021 PukiWiki Development Team
//   2001-2002 Originally written by yu-ji
// License: GPL v2 or (at your option) any later version
//
// PukiWiki Sample skin

// ------------------------------------------------------------
// Settings (define before here, if you want)

// Set site identities
$_IMAGE['skin']['logo']     = 'logo.png';
$_IMAGE['skin']['favicon']  = ''; // Sample: 'image/favicon.ico';

// SKIN_DEFAULT_DISABLE_TOPICPATH
//   1 = Show reload URL
//   0 = Show topicpath
if (! defined('SKIN_DEFAULT_DISABLE_TOPICPATH'))
	define('SKIN_DEFAULT_DISABLE_TOPICPATH', 1); // 1, 0

// Show / Hide navigation bar UI at your choice
// NOTE: This is not stop their functionalities!
if (! defined('PKWK_SKIN_SHOW_NAVBAR'))
	define('PKWK_SKIN_SHOW_NAVBAR', 1); // 1, 0

// Show / Hide toolbar UI at your choice
// NOTE: This is not stop their functionalities!
if (! defined('PKWK_SKIN_SHOW_TOOLBAR'))
	define('PKWK_SKIN_SHOW_TOOLBAR', 1); // 1, 0

// ------------------------------------------------------------
// Code start

// Prohibit direct access
if (! defined('UI_LANG')) die('UI_LANG is not set');
if (! isset($_LANG)) die('$_LANG is not set');
if (! defined('PKWK_READONLY')) die('PKWK_READONLY is not set');

$lang  = & $_LANG['skin'];
$link  = & $_LINK;
$image = & $_IMAGE['skin'];
$rw    = ! PKWK_READONLY;

// MenuBar
$menu = arg_check('read') && exist_plugin_convert('menu') ? do_plugin_convert('menu') : FALSE;
// RightBar
$rightbar = FALSE;
if (arg_check('read') && exist_plugin_convert('rightbar')) {
	$rightbar = do_plugin_convert('rightbar');
}

// ------------------------------------------------------------
// Output

// HTTP headers
pkwk_common_headers();
header('Cache-control: no-cache');
header('Pragma: no-cache');
header('Content-Type: text/html; charset=' . CONTENT_CHARSET);

?>
<!DOCTYPE html>
<html lang="ja">

<head>
  <meta charset="utf-8">
  <meta name="description" content="ここにサイトの説明">
  <meta name="keywords" content="ここにサイトのキーワード,キーワード,キーワード">
  <meta name="viewport" content="width=device-width,initial-scale=1.0">

  <title><?php echo $title ?> - <?php echo $page_title ?></title>

  <script src="skin/js/jquery-3.4.1.min.js"></script>
  <script src="skin/js/lightbox.min.js"></script>
	<!--
  <script src="skin/js/main.js" defer></script>
  <script src="skin/js/search2.js" defer></script>
  -->
  <script src="skin/js/script.js" defer></script>

  <link rel="SHORTCUT ICON" href="<?php echo $image['favicon'] ?>" />
  <link rel="stylesheet" href="skin/css/style.css"/>

  <?php echo $head_tag ?>
</head>

<body>
<?php echo $html_scripting_data ?>

  <header id="pageHeader">
    <div id="logo">
      <a href="<?php echo $link['top'] ?>"><img src="<?php echo IMAGE_DIR . $image['logo'] ?>"/></a>
    </div>
    <h1 id="pageTitle"><?php echo $page ?></h1>
    <div id="subTitle"><?php echo convert_html(get_source('SubTitle')) ?></div>
    <div id="searchBox"><?php echo convert_html(get_source('SearchBox')) ?></div>
    <div id="searchButton"><a href="<?php echo get_page_uri('Search') ?>"><i class="fas fa-search"></i></a></div>
    <div id="navButton">
      <span class="navButton-line"></span>
      <span class="navButton-line"></span>
      <span class="navButton-line"></span>
    </div>
  </header>

  <nav id="siteNavigator">
    <?php echo convert_html(get_source('MenuBar')) ?>
  </nav>

  <?php if ($menu !== FALSE) { ?>
  <div id="readMode">

    <?php if ( $title == 'SocialDesign' ) { ?>
    <div id="mySlide">
      <?php echo convert_html(get_source('Slide')) ?>
    </div>
    <?php } ?>

    <div id="main">
      <article><?php echo $body ?></article>
      <aside><?php echo convert_html(get_source('SideBar')) ?></aside>
    </div>

    <?php if ($notes != '') { ?>
    <div id="note"><?php echo $notes ?></div>
    <?php } ?>

    <?php if ($attaches != '') { ?>
    <div id="attach"><?php echo $attaches ?></div>
    <?php } ?>

    <?php if ($lastmodified != '') { ?>
    <div id="lastmodified">Last-modified: <?php echo $lastmodified ?></div>
    <?php } ?>

    <?php if ($related != '') { ?>
    <div id="related">Link: <?php echo $related ?></div>
    <?php } ?>

  </div>

  <?php } else { ?>

  <div id="editMode">
    <?php echo $body ?>
  </div>

  <?php } ?>

  <footer>
    <!-- Toolbar -->
    <div id="toolButton"><i class="fa fa-cube" aria-hidden="true"></i>
</div>
    <div id="toolbar">

      <?php
        //Set toolbar-specific images
        $_IMAGE['skin']['reload']   = '';
        $_IMAGE['skin']['new']      = '';
        $_IMAGE['skin']['edit']     = '';
        $_IMAGE['skin']['freeze']   = '';
        $_IMAGE['skin']['unfreeze'] = '';
        $_IMAGE['skin']['diff']     = '';
        $_IMAGE['skin']['upload']   = '';
        $_IMAGE['skin']['copy']     = '';
        $_IMAGE['skin']['rename']   = '';
        $_IMAGE['skin']['top']      = '';
        $_IMAGE['skin']['list']     = '';
        $_IMAGE['skin']['search']   = '';
        $_IMAGE['skin']['recent']   = '';
        $_IMAGE['skin']['backup']   = '';
        $_IMAGE['skin']['help']     = '';
        $_IMAGE['skin']['rss']      = '';
        $_IMAGE['skin']['rss10']    = '';
        $_IMAGE['skin']['rss20']    = '';
        $_IMAGE['skin']['rdf']      = '';

        function _toolbar($key, $x = 20, $y = 20){
          $lang  = & $GLOBALS['_LANG']['skin'];
          $link  = & $GLOBALS['_LINK'];
          $image = & $GLOBALS['_IMAGE']['skin'];
          if (! isset($lang[$key]) ) { echo 'LANG NOT FOUND';  return FALSE; }
          if (! isset($link[$key]) ) { echo 'LINK NOT FOUND';  return FALSE; }
          if (! isset($image[$key])) { echo 'IMAGE NOT FOUND'; return FALSE; }

          echo '<a href="' . $link[$key] . '">'.$lang[$key].'</a>';
          return TRUE;
        }

      ?>

      <?php //_toolbar('top') ?>

      <?php if ($is_page) { ?>

        <?php if ($rw) { ?>
          <?php _toolbar('edit') ?>
          <?php if ((bool)ini_get('file_uploads')) { ?>
            <?php _toolbar('upload') ?>
          <?php } ?>
          <?php _toolbar('new') ?>
          <?php _toolbar('copy') ?>
          <?php _toolbar('rename') ?>

          <?php if ($is_read && $function_freeze) { ?>
            <?php if (! $is_freeze) { _toolbar('freeze'); } else { _toolbar('unfreeze'); } ?>
          <?php } ?>
        <?php } ?>

        <?php _toolbar('diff') ?>
        <?php if ($do_backup) { ?>
          <?php _toolbar('backup') ?>
        <?php } ?>

        <?php //_toolbar('reload') ?>

      <?php } ?>

      <?php _toolbar('list')   ?>
      <?php _toolbar('search') ?>
      <?php _toolbar('recent') ?>
      <?php _toolbar('help') ?>

    </div>

    <div id="signature">
      <p>Admin: <a href="<?php echo $modifierlink ?>"><?php echo $modifier ?>　</a>
      Design: KSU SocialDesign</p>
      <p>
        <?php echo S_COPYRIGHT ?>. Powered by PHP <?php echo PHP_VERSION ?>. HTML convert time: <?php echo elapsedtime() ?> sec.</p>
    </div>

  </footer>

</body>
</html>
